rayoptics.raytr package
=======================

.. automodule:: rayoptics.raytr
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

rayoptics.raytr.analyses module
-------------------------------

.. automodule:: rayoptics.raytr.analyses
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.raytr.opticalspec module
----------------------------------

.. automodule:: rayoptics.raytr.opticalspec
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.raytr.raytrace module
-------------------------------

.. automodule:: rayoptics.raytr.raytrace
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: wave_abr, wave_abr_real_coord, wave_abr_HHH

rayoptics.raytr.sampler module
------------------------------

.. automodule:: rayoptics.raytr.sampler
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.raytr.trace module
----------------------------

.. automodule:: rayoptics.raytr.trace
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.raytr.traceerror module
---------------------------------

.. automodule:: rayoptics.raytr.traceerror
   :members:
   :undoc-members:
   :show-inheritance:

